@@ -6,6 +6,7 @@
     "FrancqZakoian2010garch"
     "Li2004diagnostic"
     "McLeodYuKrougly2007"
-    "kokoszka2011nonlinearity"))
+    "kokoszka2011nonlinearity"
+    "gardner+harvey+phillips:1980"))
  :bibtex)
 
